@@ -2,10 +2,7 @@ import sys
 sys.path.append("..")
 import seaborn as sns
 import pandas as pd
-import matplotlib.pyplot as plt
-import matplotlib.ticker as ticker
 import numpy as np
-import colorsys
 from sklearn.decomposition import PCA
 from sklearn.metrics.pairwise import manhattan_distances
 from sklearn.model_selection import train_test_split
